tarakimu package
================

Subpackages
-----------

.. toctree::

    tarakimu.cli

Submodules
----------

tarakimu\.utils module
----------------------

.. automodule:: tarakimu.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: tarakimu
    :members:
    :undoc-members:
    :show-inheritance:
